# Models - Library - NNX

Flax NNX-based neural network models for quantum device characterization.

::: inspeqtor.models.library.nnx

::: inspeqtor.models.library.nnx.WoModel

::: inspeqtor.models.library.nnx.UnitaryModel

::: inspeqtor.models.library.nnx.UnitarySPAMModel

::: inspeqtor.models.library.nnx.train_model

::: inspeqtor.models.library.nnx.make_predictive_fn

::: inspeqtor.models.library.nnx.create_step

::: inspeqtor.models.library.nnx.make_loss_fn
